@@ -1,4 +1,4 @@
-from ctypes import c_int, c_uint, c_void_p, c_char_p, c_bool, POINTER
+from ctypes import c_int, c_uint, c_uint8, c_void_p, c_char_p, c_bool, POINTER
 
 import json
 
@@ -7,7 +7,7 @@ from ..lib import lib
 from ..types.string import String
 
 from .content import ContentType
-from .headers import HttpHeader
+from .headers import http_header
 from .query import http_query_pairs_get_value
 
 RequestMethod = c_int
@@ -44,7 +44,7 @@ http_request_get_param_at_idx.argtypes = [c_void_p, c_uint]
 http_request_get_param_at_idx.restype = POINTER (String)
 
 http_request_get_header = lib.http_request_get_header
-http_request_get_header.argtypes = [c_void_p, HttpHeader]
+http_request_get_header.argtypes = [c_void_p, http_header]
 http_request_get_header.restype = POINTER (String)
 
 http_request_get_content_type = lib.http_request_get_content_type
@@ -67,6 +67,28 @@ http_request_get_body = lib.http_request_get_body
 http_request_get_body.argtypes = [c_void_p]
 http_request_get_body.restype = POINTER (String)
 
+http_request_get_current_mpart = lib.http_request_get_current_mpart
+http_request_get_current_mpart.argtypes = [c_void_p]
+http_request_get_current_mpart.restype = c_void_p
+
+http_request_get_n_files = lib.http_request_get_n_files
+http_request_get_n_files.argtypes = [c_void_p]
+http_request_get_n_files.restype = c_uint8
+
+http_request_get_n_values = lib.http_request_get_n_values
+http_request_get_n_values.argtypes = [c_void_p]
+http_request_get_n_values.restype = c_uint8
+
+http_request_get_dirname_len = lib.http_request_get_dirname_len
+http_request_get_dirname_len.argtypes = [c_void_p]
+http_request_get_dirname_len.restype = c_int
+
+http_request_get_dirname = lib.http_request_get_dirname
+http_request_get_dirname.argtypes = [c_void_p]
+http_request_get_dirname.restype = c_char_p
+
+http_request_set_dirname = lib.http_request_set_dirname
+
 http_request_get_body_values = lib.http_request_get_body_values
 http_request_get_body_values.argtypes = [c_void_p]
 http_request_get_body_values.restype = c_void_p
@@ -109,9 +131,13 @@ http_request_query_params_get_value.argtypes = [c_void_p, c_char_p]
 http_request_query_params_get_value.restype = POINTER (String)
 
 # multi-parts
+http_request_multi_parts_get = lib.http_request_multi_parts_get
+http_request_multi_parts_get.argtypes = [c_void_p, c_char_p]
+http_request_multi_parts_get.restype = c_void_p
+
 http_request_multi_parts_get_value = lib.http_request_multi_parts_get_value
 http_request_multi_parts_get_value.argtypes = [c_void_p, c_char_p]
-http_request_multi_parts_get_value.restype = POINTER (String)
+http_request_multi_parts_get_value.restype = c_char_p
 
 http_request_multi_parts_get_filename = lib.http_request_multi_parts_get_filename
 http_request_multi_parts_get_filename.argtypes = [c_void_p, c_char_p]
@@ -121,6 +147,14 @@ http_request_multi_parts_get_saved_filename = lib.http_request_multi_parts_get_s
 http_request_multi_parts_get_saved_filename.argtypes = [c_void_p, c_char_p]
 http_request_multi_parts_get_saved_filename.restype = c_char_p
 
+http_request_multi_parts_iter_start = lib.http_request_multi_parts_iter_start
+http_request_multi_parts_iter_start.argtypes = [c_void_p]
+http_request_multi_parts_iter_start.restype = c_bool
+
+http_request_multi_parts_iter_get_next = lib.http_request_multi_parts_iter_get_next
+http_request_multi_parts_iter_get_next.argtypes = [c_void_p]
+http_request_multi_parts_iter_get_next.restype = c_void_p
+
 http_request_multi_part_keep_files = lib.http_request_multi_part_keep_files
 http_request_multi_part_keep_files.argtypes = [c_void_p]
 
